# FREDOSS

This is the open-source baseline python package called `fred` package by `fred.fahera.mx` (Fahera's Research, Education, and Development Team).

## Installation

```
$ pip install fred-oss
```

By default, the `fred-oss` package will only install the `default` dependencies. You can control which
dependency set to use via the 'dependency tags' via the following pattern:

```
$ pip install 'fred-oss[<tag-1>,<tag-2>,...]'
```

Where `<tag-i>` can be:
* `default`
* `all`
* ...
